@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2021 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
@@ -28,7 +28,8 @@ from lino.core.choicelists import ChoiceListMeta
 from lino.modlib.system.choicelists import DashboardLayouts
 from lino.core.actors import Actor
 from lino.core.layouts import LayoutHandle, BaseLayout
-from lino.core.elems import LayoutElement, ComboFieldElement, SimpleRemoteComboFieldElement, FieldElement
+from lino.core.elems import (LayoutElement, ComboFieldElement,
+    SimpleRemoteComboFieldElement, FieldElement, PreviewTextFieldElement)
 from lino.core import kernel
 
 from etgen.html import E
@@ -57,8 +58,8 @@ def find(itter, target, key=None):
 
 
 class Renderer(JsRenderer, JsCacheRenderer):
-    """.
-        An JS renderer that uses the react Javascript framework.
+    """
+    A front-end renderer that uses the React Javascript framework.
     """
     is_interactive = True
     can_auth = True
@@ -585,6 +586,8 @@ class Renderer(JsRenderer, JsCacheRenderer):
                         # use c.fields_index -1 for data value
                         d.update(fields_index_hidden = d['fields_index'] + 1)
                         index_mod += 1
+                    if isinstance(col, PreviewTextFieldElement):
+                        index_mod += 2
                     columns.append(d)
                 result['col'] = columns
                 # (dict(main=self.elem2json(col_elems.main),
@@ -598,7 +601,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
                                   "hide_navigator "
                                   "use_detail_params_value "
                                   "react_responsive "
-                                  "display_mode "
+                                  "display_mode_main "
                                   "max_render_depth "
                                   "simple_slavegrid_header "
                                   "paginator_template "
@@ -655,6 +658,8 @@ class Renderer(JsRenderer, JsCacheRenderer):
         self.serialise_js_code = True
 
         for actor in self.actors_list:
+            if actor.get_handle_name is not None:
+                continue
             fn = path.join(*self.lino_js_parts_chunked(actor.actor_id))
 
             def write(f):
